Documentation
¶
Overview ¶
Package transport contains helpers applicable to all supported transports.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrorHandler ¶
ErrorHandler receives a transport error to be processed for diagnostic purposes. Usually this means logging the error.
type ErrorHandlerFunc ¶
The ErrorHandlerFunc type is an adapter to allow the use of ordinary function as ErrorHandler. If f is a function with the appropriate signature, ErrorHandlerFunc(f) is a ErrorHandler that calls f.
type LogErrorHandler ¶
type LogErrorHandler struct {
// contains filtered or unexported fields
}
LogErrorHandler is a transport error handler implementation which logs an error.
func NewLogErrorHandler ¶
func NewLogErrorHandler(logger log.Logger) *LogErrorHandler
Click to show internal directories.
Click to hide internal directories.